@@ -21,15 +21,18 @@ class MacFramelessWindow(QWidget):
         self.titleBar = TitleBar(self)
         self._isResizeEnabled = True
 
+        self.updateFrameless()
+
+        self.resize(500, 500)
+        self.titleBar.raise_()
+
+    def updateFrameless(self):
         view = objc.objc_object(c_void_p=self.winId().__int__())
         self.__nsWindow = view.window()
 
         # hide system title bar
         self.__hideSystemTitleBar()
 
-        self.resize(500, 500)
-        self.titleBar.raise_()
-
     def setTitleBar(self, titleBar):
         """ set custom title bar
 
@@ -39,6 +42,7 @@ class MacFramelessWindow(QWidget):
             title bar
         """
         self.titleBar.deleteLater()
+        self.titleBar.hide()
         self.titleBar = titleBar
         self.titleBar.setParent(self)
         self.titleBar.raise_()
